@@ -36,7 +36,6 @@ from google.appengine.ext import ndb
 from google.appengine import runtime
 from google.appengine.api import datastore_errors
 from google.appengine.api import logservice
-from google.appengine.api import modules
 from google.appengine.api import taskqueue
 from google.appengine.ext import db
 from mapreduce import base_handler
@@ -295,12 +294,7 @@ class MapperWorkerCallbackHandler(base_handler.HugeTaskHandler):
     """
     assert shard_state.slice_start_time is not None
     assert shard_state.slice_request_id is not None
-    request_ids = [shard_state.slice_request_id]
-    logs = list(logservice.fetch(
-        request_ids=request_ids,
-        # TODO(user): Remove after b/8173230 is fixed.
-        module_versions=[(os.environ["CURRENT_MODULE_ID"],
-                          modules.get_current_version_name())]))
+    logs = list(logservice.fetch(request_ids=[shard_state.slice_request_id]))
 
     if not logs or not logs[0].finished:
       return False
