@@ -41,8 +41,8 @@ import datetime
 import urllib
 import zlib
 
-from mapreduce.third_party.graphy.backends import google_chart_api
-from mapreduce.third_party import simplejson
+from graphy.backends import google_chart_api
+import simplejson
 
 from google.appengine.api import memcache
 from google.appengine.api import taskqueue
@@ -894,6 +894,7 @@ class ShardState(db.Model):
   # Functional properties.
   mapreduce_id = db.StringProperty(required=True)
   active = db.BooleanProperty(default=True, indexed=False)
+  input_finished = db.BooleanProperty(default=False, indexed=False)
   counters_map = json_util.JsonProperty(
       CountersMap, default=CountersMap(), indexed=False)
   result_status = db.StringProperty(choices=_RESULTS, indexed=False)
@@ -942,6 +943,7 @@ class ShardState(db.Model):
     self.last_work_item = ""
     self.active = True
     self.result_status = None
+    self.input_finished = False
     self.counters_map = CountersMap()
     self.slice_id = 0
     self.slice_start_time = None
@@ -974,6 +976,12 @@ class ShardState(db.Model):
     self.active = False
     self.result_status = self.RESULT_ABORTED
 
+  def set_input_finished(self):
+    self.input_finished = True
+
+  def is_input_finished(self):
+    return self.input_finished
+
   def set_for_success(self):
     self.active = False
     self.result_status = self.RESULT_SUCCESS
